@@ -1,3 +1,4 @@
+from collections import OrderedDict
 from itertools import chain
 from typing import Dict, Iterable, List, Optional, Tuple, Union
 
@@ -32,22 +33,19 @@ class PostgresQuerySet(models.QuerySet):
         Normally, the annotate function doesn't allow you to use the
         name of an existing field on the model as the alias name. This
         version of the function does allow that.
+
+        This is done by temporarily renaming the fields in order to avoid the
+        check for conflicts that the base class does.
+        We rename all fields instead of the ones that already exist because
+        the annotations are stored in an OrderedDict. Renaming only the
+        conflicts will mess up the order.
         """
-
-        fields = {field.name: field for field in self.model._meta.get_fields()}
-
-        # temporarily rename the fields that have the same
-        # name as a field name, we'll rename them back after
-        # the function in the base class ran
-        new_annotations = {}
+        new_annotations = OrderedDict()
         renames = {}
         for name, value in annotations.items():
-            if name in fields:
-                new_name = "%s_new" % name
-                new_annotations[new_name] = value
-                renames[new_name] = name
-            else:
-                new_annotations[name] = value
+            new_name = "%s_new" % name
+            new_annotations[new_name] = value
+            renames[new_name] = name
 
         # run the base class's annotate function
         result = super().annotate(**new_annotations)
